==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRequestsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ImageRegistryConfigRequestsFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent<A>{
  public ImageRegistryConfigRequestsFluentImpl() {
  }
  public ImageRegistryConfigRequestsFluentImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequests instance) {
    this.withRead(instance.getRead()); 
    this.withWrite(instance.getWrite()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder read;
  private io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder write;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRead instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits getRead() {
    return this.read!=null?this.read.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits buildRead() {
    return this.read!=null?this.read.build():null;
  }
  public A withRead(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits read) {
    _visitables.get("read").remove(this.read);
    if (read!=null){ this.read= new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(read); _visitables.get("read").add(this.read);} return (A) this;
  }
  public java.lang.Boolean hasRead() {
    return this.read != null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> withNewRead() {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluentImpl.ReadNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> withNewReadLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluentImpl.ReadNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> editRead() {
    return withNewReadLike(getRead());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> editOrNewRead() {
    return withNewReadLike(getRead() != null ? getRead(): new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> editOrNewReadLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
    return withNewReadLike(getRead() != null ? getRead(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildWrite instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits getWrite() {
    return this.write!=null?this.write.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits buildWrite() {
    return this.write!=null?this.write.build():null;
  }
  public A withWrite(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits write) {
    _visitables.get("write").remove(this.write);
    if (write!=null){ this.write= new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(write); _visitables.get("write").add(this.write);} return (A) this;
  }
  public java.lang.Boolean hasWrite() {
    return this.write != null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> withNewWrite() {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluentImpl.WriteNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> withNewWriteLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluentImpl.WriteNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> editWrite() {
    return withNewWriteLike(getWrite());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> editOrNewWrite() {
    return withNewWriteLike(getWrite() != null ? getWrite(): new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> editOrNewWriteLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
    return withNewWriteLike(getWrite() != null ? getWrite(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigRequestsFluentImpl that = (ImageRegistryConfigRequestsFluentImpl) o;
    if (read != null ? !read.equals(that.read) :that.read != null) return false;
    if (write != null ? !write.equals(that.write) :that.write != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(read,  write,  additionalProperties,  super.hashCode());
  }
  public class ReadNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ReadNestedImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(this, item);
    }
    ReadNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigRequestsFluentImpl.this.withRead(builder.build());
    }
    public N endRead() {
      return and();
    }
    
  }
  public class WriteNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    WriteNestedImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(this, item);
    }
    WriteNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigRequestsFluentImpl.this.withWrite(builder.build());
    }
    public N endWrite() {
      return and();
    }
    
  }
  
}

==> openshift-model-miscellaneous-5.12.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigRequestsFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ImageRegistryConfigRequestsFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent<A>{
  public ImageRegistryConfigRequestsFluentImpl() {
  }
  public ImageRegistryConfigRequestsFluentImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequests instance) {
    this.withRead(instance.getRead()); 
    this.withWrite(instance.getWrite()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder read;
  private io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder write;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildRead instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits getRead() {
    return this.read!=null?this.read.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits buildRead() {
    return this.read!=null?this.read.build():null;
  }
  public A withRead(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits read) {
    _visitables.get("read").remove(this.read);
    if (read!=null){ this.read= new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(read); _visitables.get("read").add(this.read);} return (A) this;
  }
  public java.lang.Boolean hasRead() {
    return this.read != null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> withNewRead() {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluentImpl.ReadNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> withNewReadLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluentImpl.ReadNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> editRead() {
    return withNewReadLike(getRead());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> editOrNewRead() {
    return withNewReadLike(getRead() != null ? getRead(): new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<A> editOrNewReadLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
    return withNewReadLike(getRead() != null ? getRead(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildWrite instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits getWrite() {
    return this.write!=null?this.write.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits buildWrite() {
    return this.write!=null?this.write.build():null;
  }
  public A withWrite(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits write) {
    _visitables.get("write").remove(this.write);
    if (write!=null){ this.write= new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(write); _visitables.get("write").add(this.write);} return (A) this;
  }
  public java.lang.Boolean hasWrite() {
    return this.write != null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> withNewWrite() {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluentImpl.WriteNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> withNewWriteLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
    return new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluentImpl.WriteNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> editWrite() {
    return withNewWriteLike(getWrite());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> editOrNewWrite() {
    return withNewWriteLike(getWrite() != null ? getWrite(): new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<A> editOrNewWriteLike(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
    return withNewWriteLike(getWrite() != null ? getWrite(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigRequestsFluentImpl that = (ImageRegistryConfigRequestsFluentImpl) o;
    if (read != null ? !read.equals(that.read) :that.read != null) return false;
    if (write != null ? !write.equals(that.write) :that.write != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(read,  write,  additionalProperties,  super.hashCode());
  }
  public class ReadNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.ReadNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ReadNestedImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(this, item);
    }
    ReadNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigRequestsFluentImpl.this.withRead(builder.build());
    }
    public N endRead() {
      return and();
    }
    
  }
  public class WriteNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsFluentImpl<io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsFluent.WriteNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    WriteNestedImpl(io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimits item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(this, item);
    }
    WriteNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1.ImageRegistryConfigRequestsLimitsBuilder builder;
    public N and() {
      return (N) ImageRegistryConfigRequestsFluentImpl.this.withWrite(builder.build());
    }
    public N endWrite() {
      return and();
    }
    
  }
  
}
